======================================
 Console Programs for Mail Processing
======================================

When this package is installed, it installs two console scripts for
processing mail queue directories using Amazon's SES via :mod:`boto3`.

nti_mailer_qp_console
=====================

.. command-output:: nti_mailer_qp_console --help

nti_mailer_qp_process
=====================

.. command-output:: nti_mailer_qp_process --help
